# Test MCP Server

使用uv搭建的建议MCP Server，用于测试uvx方式部署MCP。

## MCP 工具列表

本服务提供以下工具：


### 加法运算工具 add

将a、b两个数相加

**参数：**
- `a`: 数字a
- `b`: 数字b


### 减法运算工具 subtract

将a、b两个数相减

**参数：**
- `a`: 数字a
- `b`: 数字b


### 乘法运算工具 multiply

将a、b两个数相乘

**参数：**
- `a`: 数字a
- `b`: 数字b


### 乘法运算工具 divide

将a、b两个数相除

**参数：**
- `a`: 数字a
- `b`: 数字b